## 1.2.0.0 (2023-02-27)

Update caldav to 1.2 (#9821)

Also add a few default values and replace some instances of Any with
Incomplete.

## 1.0.0.3 (2023-02-26)

Improve many `__(a)exit__` annotations (#9696)

## 1.0.0.2 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 1.0.0.1 (2023-02-15)

Use `typing_extensions.Self` instead of `_typeshed.Self` (#9702)

## 1.0.0.0 (2023-02-03)

Update `caldav` stubs to 1.0.* (#9668)

## 0.11.0.2 (2023-01-18)

Replace `Any` with `Incomplete` in many places (#9565)

## 0.11.0.1 (2023-01-18)

Replace `Any` with `Incomplete` in many places (#9558)

## 0.11.0.0 (2022-11-25)

Bump caldav to 0.11.* (#9253)

Co-authored-by: AlexWaygood <alex.waygood@gmail.com>

## 0.10.0.0 (2022-10-31)

Update caldav stubs to 0.10 (#9044)

## 0.9.2 (2022-07-19)

Third-party stubs: enforce CamelCase for type alias names (#8256)

Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>

## 0.9.1 (2022-05-31)

caldav: add verify_expand to Calendar.date_search (#7996)

Co-authored-by: hauntsaninja <>

## 0.9.0 (2022-04-28)

Update caldav stubs for 0.9 (#7734)

## 0.8.7 (2022-04-20)

Use `TypeAlias` for type aliases where possible, part II (#7667)

## 0.8.6 (2022-01-08)

Use lowercase `type` everywhere (#6853)

## 0.8.4 (2021-12-06)

caldav: Update DAVError and AuthorizationError (#6508)

## 0.8.3 (2021-11-09)

Fix typos (#6263)

Found via `codespell -q 3 -L alo,asend,ba,nams,spawnve`

## 0.8.2 (2021-10-12)

Add star to all non-0.1 versions (#6146)

